/* $Id: update_repligard.c,v 1.2 2001/04/05 11:37:16 david Exp $
 * Generates initial GUIDs for Repligard. This should be never
 * called by anybody but Asgard maintainer. Even in the latter
 * case, it should be called only once in order to generate
 * initial GUIDs.
 */

#include <midgard/midgard.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>

/*  Touches all records from table and set their timestamps in Repligard
    If record doesn't exist in Repligard, it will be created.
*/
void mgd_repligard_touch_time(midgard * mgd, const char *table, int timestamp)
{
	midgard_res *res;

	res = mgd_ungrouped_select(mgd, "id", table, NULL, NULL);
	if (res) {
		while (mgd_fetch(res)) {
			if (mgd_exists_bool(mgd, "repligard", "id=$d AND realm=$q",
				       mgd_sql2id(res, 0), table)) {
				UPDATE_REPLIGARD_TIME(mgd, table, mgd_sql2id(res, 0), timestamp)
			}
			else {
				CREATE_REPLIGARD(mgd, table, mgd_sql2id(res, 0))
			}
		}
		mgd_release(res);
	}
}

void mgd_repligard_touch_db(midgard *mgd) {
    mgd_repligard_touch_time(mgd, "article", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "blobs", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "element", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "event", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "eventmember", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "file", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "grp", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "host", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "image", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "member", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "page", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "pageelement", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "pagelink", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "person", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "preference", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "record_extension", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "sitegroup", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "snippet", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "snippetdir", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "style", (int) time(NULL));
    mgd_repligard_touch_time(mgd, "topic", (int) time(NULL));
}

int main(int argc, char * argv[]) {
    midgard *mgd;
	if(argc < 3) {
		fprintf(stderr, "Error: missing parameters on command line\n");
		exit(1);
	}
    mgd_init();
    /* Change database name, username, and password to fit your situation */
    /* I suggest to create temporary database 'testgard' for update purposes */
    mgd = mgd_connect(argv[1], argv[2], argc > 3 ? argv[3] : "");
    if(!mgd) {
		fprintf(stderr, "Error in DB connection\n");
    	mgd_done();
		exit(1);
	}

    /* We select russian parser in order to dump content unchanged */
    mgd_select_parser(mgd, "russian");

    mgd_repligard_touch_db(mgd);

    mgd_close(mgd);
    mgd_done();
    return 0;
}
